==================================================
Essential Functions in diofant.vector (docstrings)
==================================================

matrix_to_vector
----------------

.. autofunction:: diofant.vector.matrix_to_vector

express
-------

.. autofunction:: diofant.vector.express


curl
----

.. autofunction:: diofant.vector.curl


divergence
----------

.. autofunction:: diofant.vector.divergence


gradient
--------

.. autofunction:: diofant.vector.gradient


is_conservative
---------------

.. autofunction:: diofant.vector.is_conservative


is_solenoidal
-------------

.. autofunction:: diofant.vector.is_solenoidal


scalar_potential
----------------

.. autofunction:: diofant.vector.scalar_potential


scalar_potential_difference
---------------------------

.. autofunction:: diofant.vector.scalar_potential_difference
